# Once the package is accepted into Fedora Extras, the uid should be assigned
# from the User Registry: http://fedoraproject.org/wiki/PackageUserRegistry
%if 0%{?fedora}
%define         registry_uid  %nil
%endif
%define         registry_name dbmail

%define         services dbmail-imapd dbmail-pop3d dbmail-lmtpd dbmail-timsieved

# older distros don't have sqlite
%if 0%{?fedora} && "%fedora" < "4"
%define without_sqlite 1
%endif

Name:           dbmail
Version:        2.2.9
Release:        1.2%{?dist}
Summary:        The DBMail mail storage system

Group:          System Environment/Daemons
# db_getopot.c is licensed MIT
License:        GPLv2+ and MIT
URL:            http://www.dbmail.org
Source0:        http://www.dbmail.org/download/2.2/dbmail-%{version}.tar.gz
Source1:        dbmail-imapd
Source2:        dbmail-pop3d
Source3:        dbmail-lmtpd
Source4:        dbmail-timsieved
Source5:        dbmail.cron
Source6:        dbmail.logrotate
Source7:        README.AsianuxServer3
Source8:        sql-recipients.cf
Patch1:		dbmail_notify_patch_v0.3
Patch2:		dbmail-2.2.9-sqlite-forward.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  fileutils, openssl >= 0.9.7a
BuildRequires:  glib2-devel >= 2.8,  gmime-devel >= 2.1.19
BuildRequires:  libsieve-devel >= 2.1.13
BuildRequires:  mysql-devel >= 4.1.3, postgresql-devel
BuildRequires:  openldap-devel
BuildRequires:  sed
%if ! 0%{?without_sqlite}
BuildRequires:  sqlite-devel >= 3
%endif

Requires:       glib2 >= 2.8, logrotate, initscripts, vixie-cron
Requires:       initscripts
Requires:       sed, gawk
%if 0%{?fedora}
Requires(pre):  fedora-usermgmt
Requires(postun):fedora-usermgmt
%endif
Requires:	shadow-utils

%description
Dbmail is the name of a group of programs that enable the possiblilty of
storing and retrieving mail messages from a database.

Currently dbmail supports the following database backends:
MySQL
PostgreSQL
%if ! 0%{?without_sqlite}
SQLite
%endif

Please see /usr/share/doc/dbmail-*/README.AsianuxServer3 for specific information on
installation and configuration in Asianux.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

# we don't need README.solaris and we don't want it caught up in the %%doc
# README* wildcard - but we do want our shiny new README.AsianuxServer3
# file to be installed
rm -f README.solaris
install -p -m 644 %SOURCE7 .

# make a couple of changes to the default dbmail.conf file:
# 1. default driver/authdriver pgsql/sql
# 2. default host localhost
# 3. effective uid/gid to dbmail/dbmail
sed -i -e 's/\(^driver\W*=\)\(\W*$\)/\1 pgsql/'                               \
       -e 's/\(^authdriver\W*=\)\(\W*$\)/\1 sql/' dbmail.conf
sed -i -e 's,\(^host\W*=\)\(\W*$\),\1 localhost,' dbmail.conf
sed -i -e 's/\(^EFFECTIVE_USER\W*=\)\(.*$\)/\1 %registry_name/'               \
       -e 's/\(^EFFECTIVE_GROUP\W*=\)\(.*$\)/\1 %registry_name/' dbmail.conf

# Filter out provides of private libraries
cat << \EOF > %{name}-provides
#!/bin/sh
%{__find_provides} $* |\
  sed -e '/libauth_ldap\.so/d'  \
      -e '/libauth_sql\.so/d'   \
      -e '/libsort_sieve\.so/d' \
      -e '/libsqlite\.so/d'     \
      -e '/libsqlite\.so/d'     \
      -e '/libmysql\.so/d'      \
      -e '/libpgsql\.so/d'
EOF

%define _use_internal_dependency_generator 0
%define __find_provides %{_builddir}/%{name}-%{version}/%{name}-provides
chmod +x %{__find_provides}

%build
%configure --disable-rpath \
           --disable-static \
           --with-ldap \
           --with-mysql \
           --with-pgsql \
%if ! 0%{?without_sqlite}
           --with-sqlite \
%endif
           --with-sieve

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man{1,5,8}
mkdir -p $RPM_BUILD_ROOT/%{_initrddir}
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/cron.daily
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/dbmail
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/openldap/schema/asianux
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/postfix
install -p -m 755 %SOURCE1 $RPM_BUILD_ROOT/%{_initrddir}
install -p -m 755 %SOURCE2 $RPM_BUILD_ROOT/%{_initrddir}
install -p -m 755 %SOURCE3 $RPM_BUILD_ROOT/%{_initrddir}
install -p -m 755 %SOURCE4 $RPM_BUILD_ROOT/%{_initrddir}
install -p -m 755 %SOURCE5 $RPM_BUILD_ROOT/%{_sysconfdir}/cron.daily/dbmail
install -p -m 644 %SOURCE6 $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/dbmail
install -p -m 600 dbmail.conf $RPM_BUILD_ROOT/%{_sysconfdir}/
install -p -m 644 dbmail.schema $RPM_BUILD_ROOT/%{_sysconfdir}/openldap/schema/asianux/
install -p -m 600 %SOURCE8 $RPM_BUILD_ROOT/%{_sysconfdir}/postfix
install -p -m 644 man/*1 $RPM_BUILD_ROOT/%{_mandir}/man1/
install -p -m 644 man/*5 $RPM_BUILD_ROOT/%{_mandir}/man5/
install -p -m 644 man/*8 $RPM_BUILD_ROOT/%{_mandir}/man8/
# remove libtool archives and -devel type stuff (but leave loadable modules)
find $RPM_BUILD_ROOT -name \*\.la -print | xargs rm -f
rm -f $RPM_BUILD_ROOT/%{_libdir}/dbmail/libdbmail.so

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if [ -x /usr/sbin/fedora-groupadd ] && [ -x /usr/sbin/fedora-useradd ]; then
/usr/sbin/fedora-groupadd %registry_uid -r %registry_name &> /dev/null || :
/usr/sbin/fedora-useradd  %registry_uid -r -s /sbin/nologin                   \
               -d /var/lib/dbmail                                             \
               -c "DBMail Daemon Account" -g %registry_name %registry_name    \
               &> /dev/null || :
else
  /usr/sbin/groupadd %{?registry_uid: -g %{registry_uid}} -r %registry_name &> /dev/null || :
  /usr/sbin/useradd  %{?registry_uid: -u %{registry_uid}}                    \
               -r -s /sbin/nologin -d /var/lib/dbmail                        \
               -c "DBMail Daemon Account" -g %registry_name %registry_name   \
               &> /dev/null || :
fi

%post
for s in %services; do
  /sbin/chkconfig --add $s &> /dev/null || :
done
cat <<EOT
Please install and use the DBMA package to configure dbmail
and/or local database services for dbmail.

Manual configuration can be done using the guidelines found
in the doc directory (usually /usr/share/doc/%{name}-%{version})

EOT

%preun
if [ $1 -eq 0 ]; then
  for s in %services; do
    /sbin/service $s stop &> /dev/null || : 
    /sbin/chkconfig --del $s &> /dev/null || :
  done
fi
exit 0

%postun
if [ $1 -eq 0 ]; then
  if [ -x /usr/sbin/fedora-groupdel ] && [ -x /usr/sbin/fedora-userdel ]; then
    /usr/sbin/fedora-userdel  %registry_name &> /dev/null || :
    /usr/sbin/fedora-groupdel %registry_name &> /dev/null || :
  else
    /usr/sbin/userdel  %registry_name &> /dev/null || :
    /usr/sbin/groupdel %registry_name &> /dev/null || :
  fi
elif [ $1 -ge 1 ]; then
  for s in %services; do
    /sbin/service $s condrestart &> /dev/null || : 
  done
fi	

%files
%defattr(-,root,root,-)
%doc AUTHORS BUGS ChangeLog COPYING INSTALL README* THANKS
%doc sql
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%dir %{_libdir}/dbmail
%{_libdir}/dbmail/libauth_sql*
%{_libdir}/dbmail/libdbmail*
%{_libdir}/dbmail/libsort_sieve*
%attr(0640,%registry_name,%registry_name) %config(noreplace) %{_sysconfdir}/dbmail.conf
%{_initrddir}/dbmail-*
%{_sysconfdir}/cron.daily/dbmail
%config(noreplace) %{_sysconfdir}/logrotate.d/dbmail
%config(noreplace) %{_sysconfdir}/postfix/sql-*cf
%dir %attr(0700,%registry_name,%registry_name) /var/lib/dbmail

%package auth-ldap
Summary:        The DBMail mail storage system
Group:          System Environment/Daemons
Requires:       dbmail = %{version}-%{release}, openldap

%description auth-ldap
This is the auth-ldap libraries for authentication against a ldap server with
dbmail.

%files auth-ldap
%defattr(-,root,root,-)
%attr(-,root,root) %{_libdir}/dbmail/libauth_ldap*
%config(noreplace) %{_sysconfdir}/openldap/schema/asianux

%post auth-ldap
if [ "`sed 's/[ \t]*//g' /etc/dbmail.conf | awk -F = '/^authdriver/ && (NF == 2) { print $NF }'`" != "ldap" ]
then
  sed -i 's,\(^[ \t]*authdriver\W*=\)\(.*$\),\1 ldap,' /etc/dbmail.conf
fi

%postun auth-ldap
if [ $1 -eq 0 ]; then
  if [ "`sed 's/[ \t]*//g' /etc/dbmail.conf | awk -F = '/^authdriver/ && (NF == 2) { print $NF }'`" != "sql" ]
  then
    sed -i 's,\(^[ \t]*authdriver\W*=\)\(.*$\),\1 sql,' /etc/dbmail.conf
  fi
fi

%package mysql
Summary:        The DBMail mail storage system
Group:          System Environment/Daemons
Requires:       dbmail = %{version}-%{release}, mysql >= 4.1.3

%description mysql
This is the mysql libraries for dbmail.

%files mysql
%defattr(-,root,root,-)
%doc sql/mysql/*
%{_libdir}/dbmail/libmysql*

%post mysql
if [ "`sed 's/[ \t]*//g' /etc/dbmail.conf | awk -F = '/^driver/ && (NF == 2) { print $NF }'`" != "mysql" ]
then
  sed \
      -e 's,\(^[ \t]*driver\W*=\)\(.*$\),\1 mysql,' \
      -e 's,\(^[ \t]*host\W*=\)\(.*$\),\1 localhost,' \
      -e 's,\(^[ \t]*encoding\W*=\)\(.*$\),#&\n\1 latin1,' \
      -e 's,\(^[ \t]*sqlsocket\W*=\)\(.*$\),\1 /var/lib/mysql/mysql.sock,' \
      /etc/dbmail.conf > /etc/dbmail.conf-mysql
fi

%package pgsql
Summary:        The DBMail mail storage system
Group:          System Environment/Daemons
Requires:       dbmail = %{version}-%{release}, postgresql-libs

%description pgsql
This is the postgresql libraries for dbmail.

%files pgsql
%defattr(-,root,root,-)
%doc sql/postgresql/*
%{_libdir}/dbmail/libpgsql*

%post pgsql
if [ "`sed 's/[ \t]*//g' /etc/dbmail.conf | awk -F = '/^driver/ && (NF == 2) { print $NF }'`" != "pgsql" ]
then
  sed \
      -e 's,\(^[ \t]*driver\W*=\)\(.*$\),\1 pgsql,' \
      -e 's,\(^[ \t]*host\W*=\)\(.*$\),\1 localhost,' \
      /etc/dbmail.conf > /etc/dbmail.conf-pgsql
fi

%if ! 0%{?without_sqlite}
%package sqlite
Summary:        The DBMail mail storage system
Group:          System Environment/Daemons
Requires:       dbmail = %{version}-%{release}, sqlite

%description sqlite
This is the sqlite libraries for dbmail.

%files sqlite
%defattr(-,root,root,-)
%doc sql/sqlite/*
%{_libdir}/dbmail/libsqlite*
%endif

%post sqlite
if [ "`sed -e 's/[ \t]*//g' /etc/dbmail.conf | awk -F = '/^driver/ && (NF == 2) { print $NF }'`" != "sqlite" ]
then
  sed \
      -e 's,\(^[ \t]*driver\W*=\)\(.*$\),\1 sqlite,' \
      -e 's,\(^[ \t]*host\W*=\)\(.*$\),\1 localhost,' \
      -e 's,\(^[ \t]*db\W*=\)\(.*$\),\1 /var/lib/dbmail/dbmail.db,' \
      /etc/dbmail.conf > /etc/dbmail.conf-sqlite
fi
[ ! -d /var/lib/dbmail ] && mkdir -p /var/lib/dbmail
chown -R %registry_name:%registry_name /var/lib/dbmail
chmod -R u=rwx,o= /var/lib/dbmail
if [ ! -f /var/lib/dbmail/dbmail.db ]; then
	echo Creating dbmail sqlite database at /var/lib/dbmail/dbmail.db
	sqlite3 /var/lib/dbmail/dbmail.db < %{_docdir}/%{name}-%{version}/sql/sqlite/create_tables.sqlite
	chown %registry_name:%registry_name /var/lib/dbmail/dbmail.db
	chmod o= /var/lib/dbmail/dbmail.db
else
	echo sqlite database already exists at /var/lib/dbmail/dbmail.db
fi

%changelog
* Thu Jun 26 2008 Xiao Liu <xiaoliu@redflag-linux.com> 2.2.9-1.2%{?dist}
- add patch#2 to resolve forward problem useing sqlite (AXBug#4218)
  resolve delete message in client problem useing sqlite (AXBug#4517)

* Tue May 20 2008 Masayuki MORIYAMA <moriyama@miraclelinux.com> 2.2.9-1.1%{?dist}
- Update to 2.2.9
- Write the modification of driver to dbmail.conf-{pgsql,mysql,sqlite}
- Remove Conflicts

* Mon May 12 2008 Hua Jie <jiehua@redflag-linux.com> 2.2.8-1.2%{?dist}
- add patch1 to support sieve notify
- add patch2 to fix dbmail-export problem

* Fri Mar 21 2008 Masayuki MORIYAMA <moriyama@miraclelinux.com> 2.2.8-1.1%{?dist}

- Update to 2.2.8 
  - Based on 2.2.8-1.el5
  - The dbmail.spec was based on 2.2.5-1.7AX
- Fix the problem to output the error log that dbmail.cron is useless (AX#3101)
- Fix the bug of start scripts included in 2.2.8-1.el5
- Remove asianux-vendor.patch
- Remove dbmail-database-driver in "Provides:" and "Requires:"
- Remove README.fedora
- Update README.AsianuxServer3 
- Arrange the script that modify dbmail.conf
- Move the script modifying dbmail.conf from %%trigger to %%post
- Add "Requires: sed, gawk" for dbmail.cron
- Add "BuildRequires: sed" for %%setup
- Add each other of dbmail-pgsql, dbmail-mysql, dbmail-sqlite to "Conflicts:"
- Add /var/lib/dbmail directory to %%files and remove "-m" option of useradd
- Merge the following among revisions from 2.2.4-4 to 2.2.8-1 of EPEL
  2.2.7-1:
  - license clarification
  2.2.5-4:
  - kill ld.so config
  - filter private libraries from provides (bz#245326)
  2.2.5-2 (dbmail.logrotate):
  - fix logrotate script as suggested in dbmail bug #600
  2.2.5-1:
  - change method of restarting daemons to that suggested in dbmail bug #600
  2.2.5-0.1.rc3:
  - remove unneccessary patches

* Fri Jul 19 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.5-1.7AX
- (removed) db pkgs Obsolete each other.... which breaks anaconda, ax3321

* Mon Jul 02 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.5-1.6AX
- Add Patch0 asianux-vendor.patch (update from svn rel 2696)
-  dsn bugfix, mantis617 ax3085
-  sqlauth bugfix, mantis618, ax3032
- Remove unneeded "-k" from generic useradd
- Moved Postfix integration to postfix package
- db pkgs Obsolete each other, so they can be swapped without removing & reinstalling everything.

* Tue Jun 26 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.5-1.5AX
- Set $HOME owner and permission.  fixes ax3051
- Update type in text blub at end of dbmail install
- Add Postfix integration

* Mon Jun 18 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.5-1.4AX
- Add dbmail.conf config for mysql charset (latin1), fixes ax2657
- Create sqlite db on the fly and set dbname in dbmail.conf
- Modify more settings in dbmail.conf depending on which rpms are used/removed

* Wed Jun 06 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.5-1.3AX
- Updated to 2.2.5, IMAP and memory leak fixes ax2836/2845
- Require on db-libs, not db-server, since db can be on another host
- Change some displayed comments from Fedora specific to Asianux specific

* Fri May 30 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.4-4.2AX
- Update dbmail.conf to set effective users/group to %registry_name ax2642
- Install dbmail.conf so that is owned/only readable by %registry_name ax2670
- Include dbmail.schema in dbmail-auth-ldap ax2829
- Add README.Asianux quick install quide

* Fri Mar 30 2007 Keith Hopkins <keith.hopkins@asianux.com> 2.2.4-4.1AX
- Integration work for Asianux Server 3.0
- Workaround hard dependancies for fedora-usermgmt
- Autoupdate driver/autodriver in dbmail.conf depending on subpackages
- %config: Set host to localhost if unset.
- Set owner/perms on dbmail.conf
- Include sql scripts for creating the databases into %doc
- Set a real home dir for user dbmail.

* Thu Mar 23 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.4-4
- actually APPLY the short write patch

* Thu Mar 22 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.4-3
- patch to eliminate short write messages
- use /sbin/service instead of running init scripts directly
- requires for initscripts because daemon function in initfile requires it
- modern tarballs do not require xmlto and asciidoc to build the docs
- change conditionals to give everything sqlite support unless it's built in
  the fedora buildsystem and %%{fedora} < 4

* Tue Mar 20 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.4-2
- patch to fix expunge bug

* Tue Mar 13 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.4-1
- v. 2.2.4
- remove umask patch as it's included upstream now

* Wed Feb 28 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.3-1
- v. 2.2.3
- tab removal in dbmail.conf no longer required
- libsqlite.so in not built anymore unless specified, remove fix
- libauth-ldap.so wasn't be built properly, fixed
- rework umask patch, still want a stronger umask on log files

* Tue Feb 20 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-9
- fix source0 location

* Tue Feb 20 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-8
- change /etc/dbmail.conf to mode 0600
- remove README.solaris, create README.fedora
- add ref to README.fedora in %%desc

* Tue Feb 20 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-7
- make macro tests a little more readable
- change dbmail-database to dbmail-database-driver; more descriptive
- reduce gmime reqs to 2.1.19
- specify sqlite req at 3 or greater

* Sun Feb 18 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-6
- remove bogus require for main package on mysql
- virtual depend with exact %%{version}-%%{release}
- remove extra mysql-devel BR
- update description to include sqlite if built with sqlite
- for mysql, 4.1.3 is required, not just 4.1
- add requires for vixie-cron
- move database specific docs to database subpackages

* Sun Feb 18 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-5
- fix perms on man pages

* Sat Feb 17 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-4
- fix a few things in scriptlets for consistency
- send error output from logrotate HUP to /dev/null
- explicitly require initscripts since they all use the daemon function
- use explicit %%{version}-%%{release} for provides

* Mon Feb 05 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-3
- fix typo in logrotate script
- patch umask for log files to be something more reasonable

* Sat Jan 31 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-2
- add some conditionals for not building sqlite on some product releases
- substitude \t for tab in sed so that rpmlint doesn't complain about mixing
  tabs and spaces

* Sat Jan 31 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.2-1
- add logrotate for dbmail.err
- sub packages depend on %%{version}-%%{release}
- update to 2.2.2
- remove mailbox2dbmail patch
- translate tabs to space in dbmail.conf
- remove errno race patch

* Sat Jan 13 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-7
- revert to older fedora-usermgmt macros so rpm will work with older os

* Fri Jan 12 2007 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-6
- add patch to fix errno race condition
- don't delete libsort_sieve.so, it's a module

* Thu Dec 14 2006 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-5
- fix my local svn that caused x bit on init files to sneak in

* Thu Dec 14 2006 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-4
- cleanup of spec file
- use fedora-usermgmt hooks
- split and build all database libraries
- kill modules/.libs from the module load path

* Tue Dec 05 2006 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-3
- leave the right .so files for modules

* Mon Nov 27 2006 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-2
- update with Fedora Extras style spec file

* Sat Nov 18 2006 Bernard Johnson <bjohnson@symetrix.com> 2.2.1-1.sc
- version 2.2.1

* Mon Nov 15 2006 Bernard Johnson <bjohnson@symetrix.com> 2.2.0-4.sc
- release 2.2.0-1.sc
